@@ -3,13 +3,12 @@ pub mod args;
 use {
     crate::*,
     anyhow::*,
-    argh,
+    cli_log::*,
     std::{
         path::{Path, PathBuf},
     },
 };
 
-
 fn print_analysis(path: &Path, args: &args::Args) -> Result<()> {
     let mut log_base = time!("LogBase::new", LogBase::new(&path, &args))?;
     if log_base.lines.is_empty() {
@@ -37,7 +36,7 @@ pub fn run() -> anyhow::Result<()> {
     } else {
         print_analysis(&path, &args)?;
     }
-    cli_log::log_mem(log::Level::Info);
+    log_mem(Level::Info);
     Ok(())
 }
 
